connectivity/com.nokia.carbide.remoteConnections/src/com/nokia/carbide/remoteconnections/internal/ServiceTester.java
changeset 1188 528b98544660
parent 935 3d8a32343ccb
child 1261 c144540186fe
--- a/connectivity/com.nokia.carbide.remoteConnections/src/com/nokia/carbide/remoteconnections/internal/ServiceTester.java	Thu Apr 08 15:04:26 2010 -0500
+++ b/connectivity/com.nokia.carbide.remoteConnections/src/com/nokia/carbide/remoteconnections/internal/ServiceTester.java	Thu Apr 08 15:21:44 2010 -0500
@@ -42,7 +42,7 @@
 		@Override
 		public void run() {
 			for (Set<AbstractConnectedService2> connectedServices : connectedServicesSets) {
 				// test first in the set and set status for others
 				Iterator<AbstractConnectedService2> iterator = connectedServices.iterator();
 				AbstractConnectedService2 toTest = iterator.next();
 				toTest.testStatus();
@@ -50,6 +50,7 @@
 				while (iterator.hasNext()) {
 					AbstractConnectedService2 next = iterator.next();
 					next.setStatus((Status) status);
+					next.getProperties().putAll(toTest.getProperties());
 				}
 			}
 			unregisterThread(this);
@@ -42,7 +42,7 @@
 		public void run() {
 			for (Set<AbstractConnectedService2> connectedServices : connectedServicesSets) {
-				// test first in the set and set status for others
+				// test first in the set and set status and properties for others
 				Iterator<AbstractConnectedService2> iterator = connectedServices.iterator();
 				AbstractConnectedService2 toTest = iterator.next();